@@ -51,10 +51,10 @@
 /* BOOL:BOOL (./gthumb-marshal.list:1) */
 void
 gthumb_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__BOOLEAN) (gpointer     data1,
@@ -90,10 +90,10 @@ gthumb_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
 /* BOOL:ENUM (./gthumb-marshal.list:2) */
 void
 gthumb_marshal_BOOLEAN__ENUM (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__ENUM) (gpointer     data1,
@@ -129,10 +129,10 @@ gthumb_marshal_BOOLEAN__ENUM (GClosure     *closure,
 /* BOOL:ENUM,ENUM (./gthumb-marshal.list:3) */
 void
 gthumb_marshal_BOOLEAN__ENUM_ENUM (GClosure     *closure,
-                                   GValue       *return_value,
+                                   GValue       *return_value G_GNUC_UNUSED,
                                    guint         n_param_values,
                                    const GValue *param_values,
-                                   gpointer      invocation_hint,
+                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                    gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__ENUM_ENUM) (gpointer     data1,
@@ -170,10 +170,10 @@ gthumb_marshal_BOOLEAN__ENUM_ENUM (GClosure     *closure,
 /* BOOL:INT,POINTER (./gthumb-marshal.list:4) */
 void
 gthumb_marshal_BOOLEAN__INT_POINTER (GClosure     *closure,
-                                     GValue       *return_value,
+                                     GValue       *return_value G_GNUC_UNUSED,
                                      guint         n_param_values,
                                      const GValue *param_values,
-                                     gpointer      invocation_hint,
+                                     gpointer      invocation_hint G_GNUC_UNUSED,
                                      gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__INT_POINTER) (gpointer     data1,
@@ -211,10 +211,10 @@ gthumb_marshal_BOOLEAN__INT_POINTER (GClosure     *closure,
 /* BOOL:VOID (./gthumb-marshal.list:5) */
 void
 gthumb_marshal_BOOLEAN__VOID (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
@@ -250,10 +250,10 @@ gthumb_marshal_BOOLEAN__VOID (GClosure     *closure,
 /* VOID:ENUM,BOOLEAN (./gthumb-marshal.list:7) */
 void
 gthumb_marshal_VOID__ENUM_BOOLEAN (GClosure     *closure,
-                                   GValue       *return_value,
+                                   GValue       *return_value G_GNUC_UNUSED,
                                    guint         n_param_values,
                                    const GValue *param_values,
-                                   gpointer      invocation_hint,
+                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                    gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__ENUM_BOOLEAN) (gpointer     data1,
@@ -287,10 +287,10 @@ gthumb_marshal_VOID__ENUM_BOOLEAN (GClosure     *closure,
 /* VOID:ENUM,ENUM (./gthumb-marshal.list:8) */
 void
 gthumb_marshal_VOID__ENUM_ENUM (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__ENUM_ENUM) (gpointer     data1,
@@ -330,10 +330,10 @@ gthumb_marshal_VOID__ENUM_ENUM (GClosure     *closure,
 /* VOID:INT,BOXED (./gthumb-marshal.list:12) */
 void
 gthumb_marshal_VOID__INT_BOXED (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_BOXED) (gpointer     data1,
@@ -367,10 +367,10 @@ gthumb_marshal_VOID__INT_BOXED (GClosure     *closure,
 /* VOID:INT,INT (./gthumb-marshal.list:13) */
 void
 gthumb_marshal_VOID__INT_INT (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer     data1,
@@ -404,10 +404,10 @@ gthumb_marshal_VOID__INT_INT (GClosure     *closure,
 /* VOID:POINTER,POINTER (./gthumb-marshal.list:14) */
 void
 gthumb_marshal_VOID__POINTER_POINTER (GClosure     *closure,
-                                      GValue       *return_value,
+                                      GValue       *return_value G_GNUC_UNUSED,
                                       guint         n_param_values,
                                       const GValue *param_values,
-                                      gpointer      invocation_hint,
+                                      gpointer      invocation_hint G_GNUC_UNUSED,
                                       gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__POINTER_POINTER) (gpointer     data1,
@@ -443,10 +443,10 @@ gthumb_marshal_VOID__POINTER_POINTER (GClosure     *closure,
 /* VOID:STRING,INT (./gthumb-marshal.list:16) */
 void
 gthumb_marshal_VOID__STRING_INT (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_INT) (gpointer     data1,
@@ -480,10 +480,10 @@ gthumb_marshal_VOID__STRING_INT (GClosure     *closure,
 /* VOID:STRING,INT,BOXED (./gthumb-marshal.list:17) */
 void
 gthumb_marshal_VOID__STRING_INT_BOXED (GClosure     *closure,
-                                       GValue       *return_value,
+                                       GValue       *return_value G_GNUC_UNUSED,
                                        guint         n_param_values,
                                        const GValue *param_values,
-                                       gpointer      invocation_hint,
+                                       gpointer      invocation_hint G_GNUC_UNUSED,
                                        gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_INT_BOXED) (gpointer     data1,
@@ -519,10 +519,10 @@ gthumb_marshal_VOID__STRING_INT_BOXED (GClosure     *closure,
 /* VOID:STRING,STRING (./gthumb-marshal.list:18) */
 void
 gthumb_marshal_VOID__STRING_STRING (GClosure     *closure,
-                                    GValue       *return_value,
+                                    GValue       *return_value G_GNUC_UNUSED,
                                     guint         n_param_values,
                                     const GValue *param_values,
-                                    gpointer      invocation_hint,
+                                    gpointer      invocation_hint G_GNUC_UNUSED,
                                     gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_STRING) (gpointer     data1,
