@@ -42,6 +42,7 @@
 #include "gconf-utils.h"
 #include "typedefs.h"
 #include "gth-browser.h"
+#include "preferences.h"
 
 #include "icons/layout1.xpm"
 #include "icons/layout2.xpm"
@@ -98,6 +99,18 @@ typedef struct {
 	GtkWidget  *radio_ss_direction_random;
 	GtkWidget  *spin_ss_delay;
 	GtkWidget  *toggle_ss_wrap_around;
+	GtkWidget  *toggle_ss_fading;
+
+	GtkWidget  *hotkey0;
+        GtkWidget  *hotkey1;
+        GtkWidget  *hotkey2;
+        GtkWidget  *hotkey3;
+        GtkWidget  *hotkey4;
+        GtkWidget  *hotkey5;
+        GtkWidget  *hotkey6;
+        GtkWidget  *hotkey7;
+        GtkWidget  *hotkey8;
+        GtkWidget  *hotkey9;
 
 } DialogData;
 
@@ -125,13 +138,9 @@ apply_cb (GtkWidget  *widget,
 	eel_gconf_set_boolean (PREF_USE_STARTUP_LOCATION, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->radio_use_startup)));
 
 	if (eel_gconf_get_boolean (PREF_USE_STARTUP_LOCATION, FALSE)) {
-		char *esc_path;
 		char *location;
 
-		esc_path = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton));
-		location = gnome_vfs_unescape_string (esc_path, "");
-		g_free (esc_path);
-
+		location = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton));
 		eel_gconf_set_path (PREF_STARTUP_LOCATION, location);
 		preferences_set_startup_location (location);
 		g_free (location);
@@ -140,8 +149,9 @@ apply_cb (GtkWidget  *widget,
 	/* Slide Show. */
 
 	eel_gconf_set_boolean (PREF_SLIDESHOW_WRAP_AROUND, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->toggle_ss_wrap_around)));
+	eel_gconf_set_boolean (PREF_SLIDESHOW_FADING, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->toggle_ss_fading)));
 
-	eel_gconf_set_integer (PREF_SLIDESHOW_DELAY, gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (data->spin_ss_delay)));
+	eel_gconf_set_float (PREF_SLIDESHOW_DELAY, gtk_spin_button_get_value (GTK_SPIN_BUTTON (data->spin_ss_delay)));
 
 	/**/
 
@@ -153,6 +163,17 @@ apply_cb (GtkWidget  *widget,
 		direction = GTH_DIRECTION_RANDOM;
 
 	pref_set_slideshow_direction (direction);
+
+	eel_gconf_set_string (PREF_HOTKEY0, gtk_entry_get_text (GTK_ENTRY (data->hotkey0)));
+        eel_gconf_set_string (PREF_HOTKEY1, gtk_entry_get_text (GTK_ENTRY (data->hotkey1)));
+        eel_gconf_set_string (PREF_HOTKEY2, gtk_entry_get_text (GTK_ENTRY (data->hotkey2)));
+        eel_gconf_set_string (PREF_HOTKEY3, gtk_entry_get_text (GTK_ENTRY (data->hotkey3)));
+        eel_gconf_set_string (PREF_HOTKEY4, gtk_entry_get_text (GTK_ENTRY (data->hotkey4)));
+        eel_gconf_set_string (PREF_HOTKEY5, gtk_entry_get_text (GTK_ENTRY (data->hotkey5)));
+        eel_gconf_set_string (PREF_HOTKEY6, gtk_entry_get_text (GTK_ENTRY (data->hotkey6)));
+        eel_gconf_set_string (PREF_HOTKEY7, gtk_entry_get_text (GTK_ENTRY (data->hotkey7)));
+        eel_gconf_set_string (PREF_HOTKEY8, gtk_entry_get_text (GTK_ENTRY (data->hotkey8)));
+        eel_gconf_set_string (PREF_HOTKEY9, gtk_entry_get_text (GTK_ENTRY (data->hotkey9)));	
 }
 
 
@@ -192,11 +213,8 @@ static void
 set_to_current_cb (GtkWidget  *widget,
 		   DialogData *data)
 {
-	char *esc_uri;
-
-	esc_uri = gnome_vfs_escape_host_and_path_string (gth_browser_get_current_directory (data->browser));
-	gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton), esc_uri);
-	g_free (esc_uri);
+	gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton),
+						 gth_browser_get_current_directory (data->browser));
 }
 
 
@@ -363,9 +381,6 @@ transp_type_changed_cb (GtkOptionMenu *option_menu,
 }
 
 
-
-
-
 /* create the main dialog. */
 void
 dlg_preferences (GthBrowser *browser)
@@ -430,6 +445,18 @@ dlg_preferences (GthBrowser *browser)
         data->radio_ss_direction_random = glade_xml_get_widget (data->gui, "radio_ss_direction_random");
         data->spin_ss_delay = glade_xml_get_widget (data->gui, "spin_ss_delay");
         data->toggle_ss_wrap_around = glade_xml_get_widget (data->gui, "toggle_ss_wrap_around");
+        data->toggle_ss_fading = glade_xml_get_widget (data->gui, "toggle_ss_fading");
+
+	data->hotkey0 = glade_xml_get_widget (data->gui, "hotkey0");
+        data->hotkey1 = glade_xml_get_widget (data->gui, "hotkey1");
+        data->hotkey2 = glade_xml_get_widget (data->gui, "hotkey2");
+        data->hotkey3 = glade_xml_get_widget (data->gui, "hotkey3");
+        data->hotkey4 = glade_xml_get_widget (data->gui, "hotkey4");
+        data->hotkey5 = glade_xml_get_widget (data->gui, "hotkey5");
+        data->hotkey6 = glade_xml_get_widget (data->gui, "hotkey6");
+        data->hotkey7 = glade_xml_get_widget (data->gui, "hotkey7");
+        data->hotkey8 = glade_xml_get_widget (data->gui, "hotkey8");
+        data->hotkey9 = glade_xml_get_widget (data->gui, "hotkey9");
 
 	btn_close  = glade_xml_get_widget (data->gui, "p_close_button");
 	btn_help   = glade_xml_get_widget (data->gui, "p_help_button");
@@ -452,12 +479,8 @@ dlg_preferences (GthBrowser *browser)
 
 	startup_location = eel_gconf_get_path (PREF_STARTUP_LOCATION, NULL);
 
-	if (uri_scheme_is_file (startup_location)) {
-		char *esc_uri;
-		esc_uri = gnome_vfs_escape_host_and_path_string (startup_location);
-		gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton), esc_uri);
-		g_free (esc_uri);
-	}
+	if (uri_scheme_is_file (startup_location))
+		gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton), startup_location);
 
 	g_free (startup_location);
 
@@ -519,8 +542,38 @@ dlg_preferences (GthBrowser *browser)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->radio_ss_direction_random), TRUE);
 
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (data->spin_ss_delay),
-				   (gfloat) eel_gconf_get_integer (PREF_SLIDESHOW_DELAY, 4));
+				   eel_gconf_get_float (PREF_SLIDESHOW_DELAY, 4.0));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->toggle_ss_wrap_around), eel_gconf_get_boolean (PREF_SLIDESHOW_WRAP_AROUND, FALSE));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->toggle_ss_fading), eel_gconf_get_boolean (PREF_SLIDESHOW_FADING, TRUE));
+
+	gtk_entry_set_text (GTK_ENTRY (data->hotkey0), 
+			    eel_gconf_get_string (PREF_HOTKEY0, 
+			    "gimp-remote %F"));
+
+	gtk_entry_set_text (GTK_ENTRY (data->hotkey1), 
+			    eel_gconf_get_string (PREF_HOTKEY1, 
+			    "convert %f -font Helvetica -pointsize 20 -fill white  -box '#00000080'  -gravity South -annotate +0+5 ' Copyright 2007, Your Name Here ' %n-copyright%e"));
+
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey2), 
+			    eel_gconf_get_string (PREF_HOTKEY2, 
+			    "mkdir -p %p/approved ; cp %f %p/approved/"));
+
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey3), 
+			    eel_gconf_get_string (PREF_HOTKEY3, 
+			    "uuencode %f %f | mail -s Photos your@emailaddress.com"));
+
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey4), 
+			    eel_gconf_get_string (PREF_HOTKEY4, 
+			    "rm ~/myarchive.zip; zip -j ~/myarchive %F"));
+
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey5), 
+			    eel_gconf_get_string (PREF_HOTKEY5, 
+		 	    "rm ~/myarchive.zip; zip -j ~/myarchive %F; uuencode ~/myarchive.zip ~/myarchive.zip | mail -s Photos your@emailaddress.com"));
+
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey6), eel_gconf_get_string (PREF_HOTKEY6, ""));
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey7), eel_gconf_get_string (PREF_HOTKEY7, ""));
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey8), eel_gconf_get_string (PREF_HOTKEY8, ""));
+        gtk_entry_set_text (GTK_ENTRY (data->hotkey9), eel_gconf_get_string (PREF_HOTKEY9, ""));
 
 	/* Set the signals handlers. */
 
